[llvm-commits] CVS: llvm/include/llvm/Argument.h BasicBlock.h Constant.h Constants.h Function.h GlobalValue.h GlobalVariable.h InlineAsm.h Instruction.h Value.h

Dan Gohman djg at cray.com
Fri Apr 13 11:12:29 PDT 2007



Changes in directory llvm/include/llvm:

Argument.h updated: 1.14 -> 1.15
BasicBlock.h updated: 1.63 -> 1.64
Constant.h updated: 1.35 -> 1.36
Constants.h updated: 1.145 -> 1.146
Function.h updated: 1.73 -> 1.74
GlobalValue.h updated: 1.34 -> 1.35
GlobalVariable.h updated: 1.40 -> 1.41
InlineAsm.h updated: 1.14 -> 1.15
Instruction.h updated: 1.82 -> 1.83
Value.h updated: 1.99 -> 1.100
---
Log message:

Rename Value::getValueType to getValueID, to avoid confusion with
other things named getValueType.


---
Diffs of the changes:  (+30 -30)

 Argument.h       |    2 +-
 BasicBlock.h     |    2 +-
 Constant.h       |    4 ++--
 Constants.h      |   18 +++++++++---------
 Function.h       |    2 +-
 GlobalValue.h    |    4 ++--
 GlobalVariable.h |    2 +-
 InlineAsm.h      |    2 +-
 Instruction.h    |    4 ++--
 Value.h          |   20 ++++++++++----------
 10 files changed, 30 insertions(+), 30 deletions(-)


Index: llvm/include/llvm/Argument.h
diff -u llvm/include/llvm/Argument.h:1.14 llvm/include/llvm/Argument.h:1.15
--- llvm/include/llvm/Argument.h:1.14	Fri Mar 23 13:44:11 2007
+++ llvm/include/llvm/Argument.h	Fri Apr 13 13:12:09 2007
@@ -64,7 +64,7 @@
   ///
   static inline bool classof(const Argument *) { return true; }
   static inline bool classof(const Value *V) {
-    return V->getValueType() == ArgumentVal;
+    return V->getValueID() == ArgumentVal;
   }
 };
 


Index: llvm/include/llvm/BasicBlock.h
diff -u llvm/include/llvm/BasicBlock.h:1.63 llvm/include/llvm/BasicBlock.h:1.64
--- llvm/include/llvm/BasicBlock.h:1.63	Fri Mar 23 13:44:11 2007
+++ llvm/include/llvm/BasicBlock.h	Fri Apr 13 13:12:09 2007
@@ -158,7 +158,7 @@
   /// Methods for support type inquiry through isa, cast, and dyn_cast:
   static inline bool classof(const BasicBlock *) { return true; }
   static inline bool classof(const Value *V) {
-    return V->getValueType() == Value::BasicBlockVal;
+    return V->getValueID() == Value::BasicBlockVal;
   }
 
   /// dropAllReferences() - This function causes all the subinstructions to "let


Index: llvm/include/llvm/Constant.h
diff -u llvm/include/llvm/Constant.h:1.35 llvm/include/llvm/Constant.h:1.36
--- llvm/include/llvm/Constant.h:1.35	Wed Mar  7 18:59:12 2007
+++ llvm/include/llvm/Constant.h	Fri Apr 13 13:12:09 2007
@@ -88,8 +88,8 @@
   static inline bool classof(const Constant *) { return true; }
   static inline bool classof(const GlobalValue *) { return true; }
   static inline bool classof(const Value *V) {
-    return V->getValueType() >= ConstantFirstVal &&
-           V->getValueType() <= ConstantLastVal;
+    return V->getValueID() >= ConstantFirstVal &&
+           V->getValueID() <= ConstantLastVal;
   }
 
   /// replaceUsesOfWithOnConstant - This method is a special form of


Index: llvm/include/llvm/Constants.h
diff -u llvm/include/llvm/Constants.h:1.145 llvm/include/llvm/Constants.h:1.146
--- llvm/include/llvm/Constants.h:1.145	Tue Apr 10 01:44:12 2007
+++ llvm/include/llvm/Constants.h	Fri Apr 13 13:12:09 2007
@@ -201,7 +201,7 @@
   /// @brief Methods to support type inquiry through isa, cast, and dyn_cast.
   static inline bool classof(const ConstantInt *) { return true; }
   static bool classof(const Value *V) {
-    return V->getValueType() == ConstantIntVal;
+    return V->getValueID() == ConstantIntVal;
   }
   static void ResetTrueFalse() { TheTrueVal = TheFalseVal = 0; }
 private:
@@ -239,7 +239,7 @@
   /// Methods for support type inquiry through isa, cast, and dyn_cast:
   static inline bool classof(const ConstantFP *) { return true; }
   static bool classof(const Value *V) {
-    return V->getValueType() == ConstantFPVal;
+    return V->getValueID() == ConstantFPVal;
   }
 };
 
@@ -267,7 +267,7 @@
   ///
   static bool classof(const ConstantAggregateZero *) { return true; }
   static bool classof(const Value *V) {
-    return V->getValueType() == ConstantAggregateZeroVal;
+    return V->getValueID() == ConstantAggregateZeroVal;
   }
 };
 
@@ -331,7 +331,7 @@
   /// Methods for support type inquiry through isa, cast, and dyn_cast:
   static inline bool classof(const ConstantArray *) { return true; }
   static bool classof(const Value *V) {
-    return V->getValueType() == ConstantArrayVal;
+    return V->getValueID() == ConstantArrayVal;
   }
 };
 
@@ -376,7 +376,7 @@
   /// Methods for support type inquiry through isa, cast, and dyn_cast:
   static inline bool classof(const ConstantStruct *) { return true; }
   static bool classof(const Value *V) {
-    return V->getValueType() == ConstantStructVal;
+    return V->getValueID() == ConstantStructVal;
   }
 };
 
@@ -428,7 +428,7 @@
   /// Methods for support type inquiry through isa, cast, and dyn_cast:
   static inline bool classof(const ConstantVector *) { return true; }
   static bool classof(const Value *V) {
-    return V->getValueType() == ConstantVectorVal;
+    return V->getValueID() == ConstantVectorVal;
   }
 };
 
@@ -464,7 +464,7 @@
   /// Methods for support type inquiry through isa, cast, and dyn_cast:
   static inline bool classof(const ConstantPointerNull *) { return true; }
   static bool classof(const Value *V) {
-    return V->getValueType() == ConstantPointerNullVal;
+    return V->getValueID() == ConstantPointerNullVal;
   }
 };
 
@@ -673,7 +673,7 @@
   /// Methods for support type inquiry through isa, cast, and dyn_cast:
   static inline bool classof(const ConstantExpr *) { return true; }
   static inline bool classof(const Value *V) {
-    return V->getValueType() == ConstantExprVal;
+    return V->getValueID() == ConstantExprVal;
   }
 };
 
@@ -704,7 +704,7 @@
   /// Methods for support type inquiry through isa, cast, and dyn_cast:
   static inline bool classof(const UndefValue *) { return true; }
   static bool classof(const Value *V) {
-    return V->getValueType() == UndefValueVal;
+    return V->getValueID() == UndefValueVal;
   }
 };
 


Index: llvm/include/llvm/Function.h
diff -u llvm/include/llvm/Function.h:1.73 llvm/include/llvm/Function.h:1.74
--- llvm/include/llvm/Function.h:1.73	Mon Apr  9 10:01:12 2007
+++ llvm/include/llvm/Function.h	Fri Apr 13 13:12:09 2007
@@ -220,7 +220,7 @@
   /// Methods for support type inquiry through isa, cast, and dyn_cast:
   static inline bool classof(const Function *) { return true; }
   static inline bool classof(const Value *V) {
-    return V->getValueType() == Value::FunctionVal;
+    return V->getValueID() == Value::FunctionVal;
   }
 
   /// dropAllReferences() - This method causes all the subinstructions to "let


Index: llvm/include/llvm/GlobalValue.h
diff -u llvm/include/llvm/GlobalValue.h:1.34 llvm/include/llvm/GlobalValue.h:1.35
--- llvm/include/llvm/GlobalValue.h:1.34	Sun Feb 25 15:06:13 2007
+++ llvm/include/llvm/GlobalValue.h	Fri Apr 13 13:12:09 2007
@@ -133,8 +133,8 @@
   // Methods for support type inquiry through isa, cast, and dyn_cast:
   static inline bool classof(const GlobalValue *) { return true; }
   static inline bool classof(const Value *V) {
-    return V->getValueType() == Value::FunctionVal ||
-           V->getValueType() == Value::GlobalVariableVal;
+    return V->getValueID() == Value::FunctionVal ||
+           V->getValueID() == Value::GlobalVariableVal;
   }
 };
 


Index: llvm/include/llvm/GlobalVariable.h
diff -u llvm/include/llvm/GlobalVariable.h:1.40 llvm/include/llvm/GlobalVariable.h:1.41
--- llvm/include/llvm/GlobalVariable.h:1.40	Thu Apr 12 13:32:50 2007
+++ llvm/include/llvm/GlobalVariable.h	Fri Apr 13 13:12:09 2007
@@ -132,7 +132,7 @@
   // Methods for support type inquiry through isa, cast, and dyn_cast:
   static inline bool classof(const GlobalVariable *) { return true; }
   static inline bool classof(const Value *V) {
-    return V->getValueType() == Value::GlobalVariableVal;
+    return V->getValueID() == Value::GlobalVariableVal;
   }
 };
 


Index: llvm/include/llvm/InlineAsm.h
diff -u llvm/include/llvm/InlineAsm.h:1.14 llvm/include/llvm/InlineAsm.h:1.15
--- llvm/include/llvm/InlineAsm.h:1.14	Sat Dec 16 23:15:12 2006
+++ llvm/include/llvm/InlineAsm.h	Fri Apr 13 13:12:09 2007
@@ -124,7 +124,7 @@
   // Methods for support type inquiry through isa, cast, and dyn_cast:
   static inline bool classof(const InlineAsm *) { return true; }
   static inline bool classof(const Value *V) {
-    return V->getValueType() == Value::InlineAsmVal;
+    return V->getValueID() == Value::InlineAsmVal;
   }
 };
 


Index: llvm/include/llvm/Instruction.h
diff -u llvm/include/llvm/Instruction.h:1.82 llvm/include/llvm/Instruction.h:1.83
--- llvm/include/llvm/Instruction.h:1.82	Fri Feb 23 18:55:48 2007
+++ llvm/include/llvm/Instruction.h	Fri Apr 13 13:12:09 2007
@@ -110,7 +110,7 @@
   /// Subclass classification... getOpcode() returns a member of
   /// one of the enums that is coming soon (down below)...
   ///
-  unsigned getOpcode() const { return getValueType() - InstructionVal; }
+  unsigned getOpcode() const { return getValueID() - InstructionVal; }
   const char *getOpcodeName() const {
     return getOpcodeName(getOpcode());
   }
@@ -193,7 +193,7 @@
   /// Methods for support type inquiry through isa, cast, and dyn_cast:
   static inline bool classof(const Instruction *) { return true; }
   static inline bool classof(const Value *V) {
-    return V->getValueType() >= Value::InstructionVal;
+    return V->getValueID() >= Value::InstructionVal;
   }
 
   //----------------------------------------------------------------------


Index: llvm/include/llvm/Value.h
diff -u llvm/include/llvm/Value.h:1.99 llvm/include/llvm/Value.h:1.100
--- llvm/include/llvm/Value.h:1.99	Mon Mar  5 17:06:32 2007
+++ llvm/include/llvm/Value.h	Fri Apr 13 13:12:09 2007
@@ -178,7 +178,7 @@
     ConstantLastVal  = ConstantPointerNullVal
   };
 
   /// getValueType - Return an ID for the concrete type of this object.  This is
   /// used to implement the classof checks.  This should not be used for any
   /// other purpose, as the values may change as LLVM evolves.  Also, note that
   /// for instructions, the Instruction's opcode is added to InstructionVal. So
@@ -187,7 +187,7 @@
   /// # there are more possible values for the value type than in ValueTy enum.
   /// # the InstructionVal enumerator must be the highest valued enumerator in
   ///   the ValueTy enum.
-  unsigned getValueType() const {
+  unsigned getValueID() const {
     return SubclassID;
   }
 
@@ -227,26 +227,26 @@
 // the subtype header files to test to see if the value is a subclass...
 //
 template <> inline bool isa_impl<Constant, Value>(const Value &Val) {
-  return Val.getValueType() >= Value::ConstantFirstVal &&
-         Val.getValueType() <= Value::ConstantLastVal;
+  return Val.getValueID() >= Value::ConstantFirstVal &&
+         Val.getValueID() <= Value::ConstantLastVal;
 }
 template <> inline bool isa_impl<Argument, Value>(const Value &Val) {
-  return Val.getValueType() == Value::ArgumentVal;
+  return Val.getValueID() == Value::ArgumentVal;
 }
 template <> inline bool isa_impl<InlineAsm, Value>(const Value &Val) {
-  return Val.getValueType() == Value::InlineAsmVal;
+  return Val.getValueID() == Value::InlineAsmVal;
 }
 template <> inline bool isa_impl<Instruction, Value>(const Value &Val) {
-  return Val.getValueType() >= Value::InstructionVal;
+  return Val.getValueID() >= Value::InstructionVal;
 }
 template <> inline bool isa_impl<BasicBlock, Value>(const Value &Val) {
-  return Val.getValueType() == Value::BasicBlockVal;
+  return Val.getValueID() == Value::BasicBlockVal;
 }
 template <> inline bool isa_impl<Function, Value>(const Value &Val) {
-  return Val.getValueType() == Value::FunctionVal;
+  return Val.getValueID() == Value::FunctionVal;
 }
 template <> inline bool isa_impl<GlobalVariable, Value>(const Value &Val) {
-  return Val.getValueType() == Value::GlobalVariableVal;
+  return Val.getValueID() == Value::GlobalVariableVal;
 }
 template <> inline bool isa_impl<GlobalValue, Value>(const Value &Val) {
   return isa<GlobalVariable>(Val) || isa<Function>(Val);
@@ -178,7 +178,7 @@
   };
 
-  /// getValueType - Return an ID for the concrete type of this object.  This is
+  /// getValueID - Return an ID for the concrete type of this object.  This is
   /// used to implement the classof checks.  This should not be used for any
   /// other purpose, as the values may change as LLVM evolves.  Also, note that






More information about the llvm-commits mailing list